// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
using System;
using System.Runtime.InteropServices;
using System.Runtime.CompilerServices;
using System.Text;
using Silk.NET.Core;
using Silk.NET.Core.Native;
using Silk.NET.Core.Attributes;
using Silk.NET.Core.Contexts;
using Silk.NET.Core.Loader;

#pragma warning disable 1591

namespace Silk.NET.Direct3D.Compilers
{
    public unsafe partial class D3DCompiler : NativeAPI
    {
        [NativeName("Type", "")]
        [NativeName("Name", "D3DCOMPILER_DLL_W")]
        public const string CompilerDllW = unchecked((string) "d3dcompiler_47.dll");
        [NativeName("Type", "")]
        [NativeName("Name", "D3DCOMPILER_DLL_A")]
        public const string CompilerDllA = unchecked((string) "d3dcompiler_47.dll");
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_COMPILER_VERSION")]
        public const int CompilerVersion = unchecked((int) 0x2F);
        [NativeName("Type", "")]
        [NativeName("Name", "D3DCOMPILER_DLL")]
        public const string CompilerDll = unchecked((string) "d3dcompiler_47.dll");
        [NativeName("Type", "int")]
        [NativeName("Name", "D3DCOMPILE_OPTIMIZATION_LEVEL1")]
        public const int CompileOptimizationLevel1 = unchecked((int) 0x0);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3DCOMPILE_FLAGS2_FORCE_ROOT_SIGNATURE_LATEST")]
        public const int CompileFlags2ForceRootSignatureLatest = unchecked((int) 0x0);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3DCOMPILE_SECDATA_MERGE_UAV_SLOTS")]
        public const int CompileSecdataMergeUavSlots = unchecked((int) 0x1);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3DCOMPILE_SECDATA_PRESERVE_TEMPLATE_SLOTS")]
        public const int CompileSecdataPreserveTemplateSlots = unchecked((int) 0x2);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3DCOMPILE_SECDATA_REQUIRE_TEMPLATE_MATCH")]
        public const int CompileSecdataRequireTemplateMatch = unchecked((int) 0x4);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_ENABLE_COLOR_CODE")]
        public const int DisasmEnableColorCode = unchecked((int) 0x1);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_ENABLE_DEFAULT_VALUE_PRINTS")]
        public const int DisasmEnableDefaultValuePrints = unchecked((int) 0x2);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_ENABLE_INSTRUCTION_NUMBERING")]
        public const int DisasmEnableInstructionNumbering = unchecked((int) 0x4);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_ENABLE_INSTRUCTION_CYCLE")]
        public const int DisasmEnableInstructionCycle = unchecked((int) 0x8);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_DISABLE_DEBUG_INFO")]
        public const int DisasmDisableDebugInfo = unchecked((int) 0x10);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_ENABLE_INSTRUCTION_OFFSET")]
        public const int DisasmEnableInstructionOffset = unchecked((int) 0x20);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_INSTRUCTION_ONLY")]
        public const int DisasmInstructionOnly = unchecked((int) 0x40);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_DISASM_PRINT_HEX_LITERALS")]
        public const int DisasmPrintHexLiterals = unchecked((int) 0x80);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_GET_INST_OFFSETS_INCLUDE_NON_EXECUTABLE")]
        public const int GetInstOffsetsIncludeNonExecutable = unchecked((int) 0x1);
        [NativeName("Type", "int")]
        [NativeName("Name", "D3D_COMPRESS_SHADER_KEEP_ALL_PARTS")]
        public const int CompressShaderKeepAllParts = unchecked((int) 0x1);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob(char* pFileName, Silk.NET.Core.Native.ID3D10Blob** ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob(char* pFileName, ref Silk.NET.Core.Native.ID3D10Blob* ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob(ref char pFileName, Silk.NET.Core.Native.ID3D10Blob** ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob(ref char pFileName, ref Silk.NET.Core.Native.ID3D10Blob* ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.ID3D10Blob** ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 51, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReadFileToBlob")]
        public unsafe partial int ReadFileToBlob([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.ID3D10Blob* ppContents);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public unsafe partial int WriteBlobToFile(Silk.NET.Core.Native.ID3D10Blob* pBlob, char* pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public unsafe partial int WriteBlobToFile(Silk.NET.Core.Native.ID3D10Blob* pBlob, ref char pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public unsafe partial int WriteBlobToFile(Silk.NET.Core.Native.ID3D10Blob* pBlob, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public unsafe partial int WriteBlobToFile(ref Silk.NET.Core.Native.ID3D10Blob pBlob, char* pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public partial int WriteBlobToFile(ref Silk.NET.Core.Native.ID3D10Blob pBlob, ref char pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 61, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DWriteBlobToFile")]
        public partial int WriteBlobToFile(ref Silk.NET.Core.Native.ID3D10Blob pBlob, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, int bOverwrite);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 210, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile")]
        public unsafe partial int Compile<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T0 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, void* pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 240, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompile2")]
        public unsafe partial int Compile2<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, uint SecondaryDataFlags, ref T1 pSecondaryData, nuint SecondaryDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(char* pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile(ref char pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, byte* pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref byte pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, byte* pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, ref byte pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, Silk.NET.Core.Native.ID3D10Blob** ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 256, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompileFromFile")]
        public unsafe partial int CompileFromFile([UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPWStr)] string pFileName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pEntrypoint, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pTarget, uint Flags1, uint Flags2, ref Silk.NET.Core.Native.ID3D10Blob* ppCode, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess(void* pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, byte* pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, ref byte pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, Silk.NET.Core.Native.D3DShaderMacro* pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, Silk.NET.Core.Native.ID3DInclude* pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, Silk.NET.Core.Native.ID3D10Blob** ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, Silk.NET.Core.Native.ID3D10Blob** ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 274, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DPreprocess")]
        public unsafe partial int Preprocess<T0>(ref T0 pSrcData, nuint SrcDataSize, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string pSourceName, ref Silk.NET.Core.Native.D3DShaderMacro pDefines, ref Silk.NET.Core.Native.ID3DInclude pInclude, ref Silk.NET.Core.Native.ID3D10Blob* ppCodeText, ref Silk.NET.Core.Native.ID3D10Blob* ppErrorMsgs) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 299, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetDebugInfo")]
        public unsafe partial int GetDebugInfo(void* pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppDebugInfo);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 299, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetDebugInfo")]
        public unsafe partial int GetDebugInfo(void* pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppDebugInfo);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 299, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetDebugInfo")]
        public unsafe partial int GetDebugInfo<T0>(ref T0 pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppDebugInfo) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 299, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetDebugInfo")]
        public unsafe partial int GetDebugInfo<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppDebugInfo) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect(void* pSrcData, nuint SrcDataSize, Guid* pInterface, void** ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect(void* pSrcData, nuint SrcDataSize, Guid* pInterface, ref void* ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect(void* pSrcData, nuint SrcDataSize, ref Guid pInterface, void** ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect(void* pSrcData, nuint SrcDataSize, ref Guid pInterface, ref void* ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect<T0>(ref T0 pSrcData, nuint SrcDataSize, Guid* pInterface, void** ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect<T0>(ref T0 pSrcData, nuint SrcDataSize, Guid* pInterface, ref void* ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Guid pInterface, void** ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 311, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflect")]
        public unsafe partial int Reflect<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Guid pInterface, ref void* ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary(void* pSrcData, nuint SrcDataSize, Guid* riid, void** ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary(void* pSrcData, nuint SrcDataSize, Guid* riid, ref void* ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary(void* pSrcData, nuint SrcDataSize, ref Guid riid, void** ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary(void* pSrcData, nuint SrcDataSize, ref Guid riid, ref void* ppReflector);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary<T0>(ref T0 pSrcData, nuint SrcDataSize, Guid* riid, void** ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary<T0>(ref T0 pSrcData, nuint SrcDataSize, Guid* riid, ref void* ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Guid riid, void** ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 324, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DReflectLibrary")]
        public unsafe partial int ReflectLibrary<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Guid riid, ref void* ppReflector) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 345, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble")]
        public unsafe partial int Disassemble<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion(void* pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, byte* szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, ref byte szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, nuint* pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 359, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassembleRegion")]
        public unsafe partial int DisassembleRegion<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, [UnmanagedType(Silk.NET.Core.Native.UnmanagedType.LPStr)] string szComments, nuint StartByteOffset, nuint NumInsts, ref nuint pFinishByteOffset, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 372, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateLinker")]
        public unsafe partial int CreateLinker(void** ppLinker);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 372, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateLinker")]
        public unsafe partial int CreateLinker(ref void* ppLinker);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 375, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DLoadModule")]
        public unsafe partial int LoadModule(void* pSrcData, nuint cbSrcDataSize, void** ppModule);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 375, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DLoadModule")]
        public unsafe partial int LoadModule(void* pSrcData, nuint cbSrcDataSize, ref void* ppModule);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 375, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DLoadModule")]
        public unsafe partial int LoadModule<T0>(ref T0 pSrcData, nuint cbSrcDataSize, void** ppModule) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 375, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DLoadModule")]
        public unsafe partial int LoadModule<T0>(ref T0 pSrcData, nuint cbSrcDataSize, ref void* ppModule) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 380, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateFunctionLinkingGraph")]
        public unsafe partial int CreateFunctionLinkingGraph(uint uFlags, void** ppFunctionLinkingGraph);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 380, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateFunctionLinkingGraph")]
        public unsafe partial int CreateFunctionLinkingGraph(uint uFlags, ref void* ppFunctionLinkingGraph);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets(void* pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, nuint* pOffsets, nuint* pTotalInsts);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets(void* pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, nuint* pOffsets, ref nuint pTotalInsts);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets(void* pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, ref nuint pOffsets, nuint* pTotalInsts);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets(void* pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, ref nuint pOffsets, ref nuint pTotalInsts);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, nuint* pOffsets, nuint* pTotalInsts) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, nuint* pOffsets, ref nuint pTotalInsts) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public unsafe partial int GetTraceInstructionOffsets<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, ref nuint pOffsets, nuint* pTotalInsts) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 394, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetTraceInstructionOffsets")]
        public partial int GetTraceInstructionOffsets<T0>(ref T0 pSrcData, nuint SrcDataSize, uint Flags, nuint StartInstIndex, nuint NumInsts, ref nuint pOffsets, ref nuint pTotalInsts) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 409, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputSignatureBlob")]
        public unsafe partial int GetInputSignatureBlob(void* pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 409, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputSignatureBlob")]
        public unsafe partial int GetInputSignatureBlob(void* pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 409, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputSignatureBlob")]
        public unsafe partial int GetInputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 409, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputSignatureBlob")]
        public unsafe partial int GetInputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 420, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetOutputSignatureBlob")]
        public unsafe partial int GetOutputSignatureBlob(void* pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 420, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetOutputSignatureBlob")]
        public unsafe partial int GetOutputSignatureBlob(void* pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 420, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetOutputSignatureBlob")]
        public unsafe partial int GetOutputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 420, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetOutputSignatureBlob")]
        public unsafe partial int GetOutputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 431, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputAndOutputSignatureBlob")]
        public unsafe partial int GetInputAndOutputSignatureBlob(void* pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 431, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputAndOutputSignatureBlob")]
        public unsafe partial int GetInputAndOutputSignatureBlob(void* pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 431, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputAndOutputSignatureBlob")]
        public unsafe partial int GetInputAndOutputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, Silk.NET.Core.Native.ID3D10Blob** ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 431, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetInputAndOutputSignatureBlob")]
        public unsafe partial int GetInputAndOutputSignatureBlob<T0>(ref T0 pSrcData, nuint SrcDataSize, ref Silk.NET.Core.Native.ID3D10Blob* ppSignatureBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 452, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DStripShader")]
        public unsafe partial int StripShader(void* pShaderBytecode, nuint BytecodeLength, uint uStripFlags, Silk.NET.Core.Native.ID3D10Blob** ppStrippedBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 452, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DStripShader")]
        public unsafe partial int StripShader(void* pShaderBytecode, nuint BytecodeLength, uint uStripFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppStrippedBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 452, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DStripShader")]
        public unsafe partial int StripShader<T0>(ref T0 pShaderBytecode, nuint BytecodeLength, uint uStripFlags, Silk.NET.Core.Native.ID3D10Blob** ppStrippedBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 452, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DStripShader")]
        public unsafe partial int StripShader<T0>(ref T0 pShaderBytecode, nuint BytecodeLength, uint uStripFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppStrippedBlob) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 488, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetBlobPart")]
        public unsafe partial int GetBlobPart(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, Silk.NET.Core.Native.ID3D10Blob** ppPart);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 488, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetBlobPart")]
        public unsafe partial int GetBlobPart(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref Silk.NET.Core.Native.ID3D10Blob* ppPart);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 488, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetBlobPart")]
        public unsafe partial int GetBlobPart<T0>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, Silk.NET.Core.Native.ID3D10Blob** ppPart) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 488, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DGetBlobPart")]
        public unsafe partial int GetBlobPart<T0>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref Silk.NET.Core.Native.ID3D10Blob* ppPart) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, void* pPart, nuint PartSize, Silk.NET.Core.Native.ID3D10Blob** ppNewShader);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, void* pPart, nuint PartSize, ref Silk.NET.Core.Native.ID3D10Blob* ppNewShader);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0>(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref T0 pPart, nuint PartSize, Silk.NET.Core.Native.ID3D10Blob** ppNewShader) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0>(void* pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref T0 pPart, nuint PartSize, ref Silk.NET.Core.Native.ID3D10Blob* ppNewShader) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, void* pPart, nuint PartSize, Silk.NET.Core.Native.ID3D10Blob** ppNewShader) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, void* pPart, nuint PartSize, ref Silk.NET.Core.Native.ID3D10Blob* ppNewShader) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref T1 pPart, nuint PartSize, Silk.NET.Core.Native.ID3D10Blob** ppNewShader) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 501, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DSetBlobPart")]
        public unsafe partial int SetBlobPart<T0, T1>(ref T0 pSrcData, nuint SrcDataSize, BlobPart Part, uint Flags, ref T1 pPart, nuint PartSize, ref Silk.NET.Core.Native.ID3D10Blob* ppNewShader) where T0 : unmanaged where T1 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 516, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateBlob")]
        public unsafe partial int CreateBlob(nuint Size, Silk.NET.Core.Native.ID3D10Blob** ppBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 516, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCreateBlob")]
        public unsafe partial int CreateBlob(nuint Size, ref Silk.NET.Core.Native.ID3D10Blob* ppBlob);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 534, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompressShaders")]
        public unsafe partial int CompressShaders(uint uNumShaders, ShaderData* pShaderData, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppCompressedData);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 534, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompressShaders")]
        public unsafe partial int CompressShaders(uint uNumShaders, ShaderData* pShaderData, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppCompressedData);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 534, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompressShaders")]
        public unsafe partial int CompressShaders(uint uNumShaders, ref ShaderData pShaderData, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppCompressedData);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 534, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DCompressShaders")]
        public unsafe partial int CompressShaders(uint uNumShaders, ref ShaderData pShaderData, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppCompressedData);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, uint* pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, ref uint pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, uint* pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, ref uint pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, uint* pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, ref uint pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, uint* pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders(void* pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, ref uint pTotalShaders);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, uint* pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, ref uint pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, uint* pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, uint* pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, ref uint pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, uint* pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, Silk.NET.Core.Native.ID3D10Blob** ppShaders, ref uint pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, uint* pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 546, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDecompressShaders")]
        public unsafe partial int DecompressShaders<T0>(ref T0 pSrcData, nuint SrcDataSize, uint uNumShaders, uint uStartIndex, ref uint pIndices, uint uFlags, ref Silk.NET.Core.Native.ID3D10Blob* ppShaders, ref uint pTotalShaders) where T0 : unmanaged;

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 570, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble10Effect")]
        public unsafe partial int Disassemble10Effect(ID3D10Effect* pEffect, uint Flags, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 570, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble10Effect")]
        public unsafe partial int Disassemble10Effect(ID3D10Effect* pEffect, uint Flags, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 570, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble10Effect")]
        public unsafe partial int Disassemble10Effect(ref ID3D10Effect pEffect, uint Flags, Silk.NET.Core.Native.ID3D10Blob** ppDisassembly);

        /// <summary>To be documented.</summary>
        [NativeName("Src", "Line 570, Column 1 in d3dcompiler.h")]
        [NativeApi(EntryPoint = "D3DDisassemble10Effect")]
        public unsafe partial int Disassemble10Effect(ref ID3D10Effect pEffect, uint Flags, ref Silk.NET.Core.Native.ID3D10Blob* ppDisassembly);


        public D3DCompiler(INativeContext ctx)
            : base(ctx)
        {
        }
    }
}

